CanonSpecification

Struct CanonSpecification 

pub struct CanonSpecification {
    pub canon: String,
    pub type: String,
    pub metadata: SpecificationMetadata,
    pub includes: Option<Vec<String>>,
    pub schema: Option<HashMap<String, SchemaField>>,
    pub content: HashMap<String, Value>,
}
Canon Protocol Specification

This represents ANY Canon document - whether it’s a type definition, a project specification, or any other kind of Canon specification. The type field determines what kind of specification this is.

Fields

canon: String

Protocol version (e.g., “1.0”)

type: String

Type reference - determines what kind of specification this is Examples:

  • “canon-protocol.org/type@1.0.0” for type definitions
  • “canon-protocol.org/project@1.0.0” for projects
  • “content.org/blog-post@1.0.0” for a blog post
metadata: SpecificationMetadata

Required metadata for all specifications

includes: Option<Vec<String>>

Optional includes for type composition (used when this is a type definition)

schema: Option<HashMap<String, SchemaField>>

Optional schema definition (only present when this is a type definition)

content: HashMap<String, Value>

Type-specific content (any fields defined by the type’s schema)